Changelog
=========

0.0.2 (2025-01-14)
------------------

- `init_logging` now supports specifying `stream` or `filename` or `handlers` as well as the `log_format`


0.0.1 (2023-11-30)
------------------

- initial release

